@@ -2682,245 +2682,240 @@ break;
 case 289:
 # 800 "yacc.ym"
 {
-id objcT10;
-
-# 801 "yacc.ym"
-if(o_refcnt&& !(objcT10=yyvsp[0],(*(BOOL(*)(id,SEL))_imp(objcT10,selTransTbl[2]))(objcT10,selTransTbl[2]))){
-yyval=mkcompstmt((id)0,(id)0,mklist((id)0,yyvsp[0]),(id)0);
-}else{
+# 806 "yacc.ym"
 yyval=yyvsp[0];
-}
+# 810 "yacc.ym"
 }
 break;
 case 290:
-# 810 "yacc.ym"
+# 814 "yacc.ym"
 {yyval=mkexprstmt(yyvsp[ -1]);}
 break;
 case 291:
-# 812 "yacc.ym"
+# 816 "yacc.ym"
 {yyval=yyvsp[0];}
 break;
 case 292:
-# 814 "yacc.ym"
+# 818 "yacc.ym"
 {yyval=mklabeledstmt(yyvsp[ -2],yyvsp[0]);}
 break;
 case 293:
-# 816 "yacc.ym"
+# 820 "yacc.ym"
 {yyval=mkcasestmt(yyvsp[ -3],yyvsp[ -2],yyvsp[0]);}
 break;
 case 294:
-# 818 "yacc.ym"
+# 822 "yacc.ym"
 {yyval=mkdefaultstmt(yyvsp[ -2],yyvsp[0]);}
 break;
 case 295:
-# 820 "yacc.ym"
+# 824 "yacc.ym"
 {yyval=mkifstmt(yyvsp[ -4],yyvsp[ -2],yyvsp[0]);}
 break;
 case 296:
-# 822 "yacc.ym"
+# 826 "yacc.ym"
 {yyval=mkifelsestmt(yyvsp[ -6],yyvsp[ -4],yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
 break;
 case 297:
-# 824 "yacc.ym"
+# 828 "yacc.ym"
 {yyval=mkswitchstmt(yyvsp[ -4],yyvsp[ -2],yyvsp[0]);}
 break;
 case 298:
-# 826 "yacc.ym"
+# 830 "yacc.ym"
 {yyval=mkwhilestmt(yyvsp[ -4],yyvsp[ -2],yyvsp[0]);}
 break;
 case 299:
-# 828 "yacc.ym"
+# 832 "yacc.ym"
 {yyval=mkdostmt(yyvsp[ -6],yyvsp[ -5],yyvsp[ -4],yyvsp[ -2]);}
 break;
 case 300:
-# 830 "yacc.ym"
+# 834 "yacc.ym"
 {yyval=mkforstmt(yyvsp[ -8],yyvsp[ -6],yyvsp[ -4],yyvsp[ -2],yyvsp[0]);}
 break;
 case 301:
-# 832 "yacc.ym"
+# 836 "yacc.ym"
 {yyval=mkgotostmt(yyvsp[ -2],yyvsp[ -1]);}
 break;
 case 302:
-# 834 "yacc.ym"
+# 838 "yacc.ym"
 {yyval=mkcontinuestmt(yyvsp[ -1]);}
 break;
 case 303:
-# 836 "yacc.ym"
+# 840 "yacc.ym"
 {yyval=mkbreakstmt(yyvsp[ -1]);}
 break;
 case 304:
-# 838 "yacc.ym"
+# 842 "yacc.ym"
 {yyval=mkreturnstmt(yyvsp[ -1],(id)0);}
 break;
 case 305:
-# 840 "yacc.ym"
+# 844 "yacc.ym"
 {yyval=mkreturnstmt(yyvsp[ -2],yyvsp[ -1]);}
 break;
 case 306:
-# 842 "yacc.ym"
-{yyval=yyvsp[0];}
-break;
-case 307:
-# 844 "yacc.ym"
-{yyval=yyvsp[0];}
-break;
-case 308:
 # 846 "yacc.ym"
 {yyval=yyvsp[0];}
 break;
-case 309:
+case 307:
+# 848 "yacc.ym"
+{yyval=yyvsp[0];}
+break;
+case 308:
 # 850 "yacc.ym"
+{yyval=yyvsp[0];}
+break;
+case 309:
+# 854 "yacc.ym"
 {yyval=mklist((id)0,yyvsp[0]);}
 break;
 case 310:
-# 852 "yacc.ym"
+# 856 "yacc.ym"
 {yyval=mklist(yyvsp[ -1],yyvsp[0]);}
 break;
 case 311:
-# 856 "yacc.ym"
+# 860 "yacc.ym"
 {yyval=mklist((id)0,yyvsp[0]);}
 break;
 case 312:
-# 858 "yacc.ym"
+# 862 "yacc.ym"
 {yyval=mklist(yyvsp[ -1],yyvsp[0]);}
 break;
 case 313:
-# 862 "yacc.ym"
+# 866 "yacc.ym"
 {yyval=yyvsp[0];}
 break;
 case 314:
-# 864 "yacc.ym"
+# 868 "yacc.ym"
 {yyval=mkbinexpr(yyvsp[ -2],"*",yyvsp[0]);}
 break;
 case 315:
-# 866 "yacc.ym"
+# 870 "yacc.ym"
 {yyval=mkbinexpr(yyvsp[ -2],"/",yyvsp[0]);}
 break;
 case 316:
-# 868 "yacc.ym"
+# 872 "yacc.ym"
 {yyval=mkbinexpr(yyvsp[ -2],"%",yyvsp[0]);}
 break;
 case 317:
-# 872 "yacc.ym"
+# 876 "yacc.ym"
 {procextdef(yyvsp[0]);}
 break;
 case 318:
-# 874 "yacc.ym"
+# 878 "yacc.ym"
 {procextdef(yyvsp[0]);}
 break;
 case 319:
-# 878 "yacc.ym"
+# 882 "yacc.ym"
 {yyval=mktypename(yyvsp[0],(id)0);}
 break;
 case 320:
-# 880 "yacc.ym"
+# 884 "yacc.ym"
 {yyval=mktypename(yyvsp[ -1],yyvsp[0]);}
 break;
 case 321:
-# 884 "yacc.ym"
-{yyval=yyvsp[0];}
-break;
-case 322:
-# 886 "yacc.ym"
-{yyval=yyvsp[0];}
-break;
-case 323:
 # 888 "yacc.ym"
 {yyval=yyvsp[0];}
 break;
-case 324:
+case 322:
 # 890 "yacc.ym"
 {yyval=yyvsp[0];}
 break;
-case 325:
+case 323:
 # 892 "yacc.ym"
 {yyval=yyvsp[0];}
 break;
-case 326:
+case 324:
 # 894 "yacc.ym"
+{yyval=yyvsp[0];}
+break;
+case 325:
+# 896 "yacc.ym"
+{yyval=yyvsp[0];}
+break;
+case 326:
+# 898 "yacc.ym"
 {yyval=mktypeof(yyvsp[ -3],yyvsp[ -1]);}
 break;
 case 327:
-# 898 "yacc.ym"
+# 902 "yacc.ym"
 {yyval=mklist((id)0,yyvsp[0]);}
 break;
 case 328:
-# 900 "yacc.ym"
+# 904 "yacc.ym"
 {yyval=mklist(yyvsp[ -1],yyvsp[0]);}
 break;
 case 329:
-# 904 "yacc.ym"
+# 908 "yacc.ym"
 {yyval=mklist((id)0,yyvsp[0]);}
 break;
 case 330:
-# 906 "yacc.ym"
+# 910 "yacc.ym"
 {yyval=mklist(yyvsp[ -1],yyvsp[0]);}
 break;
 case 331:
-# 910 "yacc.ym"
+# 914 "yacc.ym"
 {yyval=yyvsp[0];}
 break;
 case 332:
-# 912 "yacc.ym"
+# 916 "yacc.ym"
+{
+id objcT10;
+
+# 916 "yacc.ym"
+yyval=mkunaryexpr((objcT10=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT10,selTransTbl[0]))(objcT10,selTransTbl[0])),yyvsp[0]);}
+break;
+case 333:
+# 918 "yacc.ym"
 {
 id objcT11;
 
-# 912 "yacc.ym"
+# 918 "yacc.ym"
 yyval=mkunaryexpr((objcT11=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT11,selTransTbl[0]))(objcT11,selTransTbl[0])),yyvsp[0]);}
 break;
-case 333:
-# 914 "yacc.ym"
-{
-id objcT12;
-
-# 914 "yacc.ym"
-yyval=mkunaryexpr((objcT12=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT12,selTransTbl[0]))(objcT12,selTransTbl[0])),yyvsp[0]);}
-break;
 case 334:
-# 916 "yacc.ym"
+# 920 "yacc.ym"
 {yyval=mkunaryexpr("!",yyvsp[0]);}
 break;
 case 335:
-# 918 "yacc.ym"
+# 922 "yacc.ym"
 {yyval=mkunaryexpr("~",yyvsp[0]);}
 break;
 case 336:
-# 920 "yacc.ym"
+# 924 "yacc.ym"
 {yyval=mkaddressof(yyvsp[0]);}
 break;
 case 337:
-# 922 "yacc.ym"
+# 926 "yacc.ym"
 {yyval=mkdereference(yyvsp[0]);}
 break;
 case 338:
-# 924 "yacc.ym"
+# 928 "yacc.ym"
 {yyval=mkunaryexpr("+",yyvsp[0]);}
 break;
 case 339:
-# 926 "yacc.ym"
+# 930 "yacc.ym"
 {yyval=mkunaryexpr("-",yyvsp[0]);}
 break;
 case 340:
-# 928 "yacc.ym"
+# 932 "yacc.ym"
 {yyval=mksizeof(yyvsp[0]);}
 break;
 case 341:
-# 930 "yacc.ym"
+# 934 "yacc.ym"
 {yyval=mkbuiltincall(yyvsp[ -3],mklist((id)0,yyvsp[ -1]));}
 break;
 case 342:
-# 932 "yacc.ym"
+# 936 "yacc.ym"
 {yyval=mkbuiltincall(yyvsp[ -3],yyvsp[ -1]);}
 break;
 case 343:
-# 934 "yacc.ym"
+# 938 "yacc.ym"
 {
-id objcT13;
+id objcT12;
 
-# 934 "yacc.ym"
-yyval=mkunaryexpr((objcT13=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT13,selTransTbl[0]))(objcT13,selTransTbl[0])),yyvsp[0]);}
+# 938 "yacc.ym"
+yyval=mkunaryexpr((objcT12=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT12,selTransTbl[0]))(objcT12,selTransTbl[0])),yyvsp[0]);}
 break;
-# 3102 "y.tab.c"
+# 3106 "y.tab.c"
 }
 yyssp-=yym;
 yystate= *yyssp;
@@ -2928,14 +2923,14 @@ yyvsp-=yym;
 yym=yylhs[yyn];
 if(yystate==0&&yym==0)
 {
-# 3114 "y.tab.c"
+# 3118 "y.tab.c"
 yystate=22; * ++
 yyssp=22; * ++
 yyvsp=yyval;
 if(yychar<0)
 {
 if((yychar=yylex())<0)yychar=0;
-# 3130 "y.tab.c"
+# 3134 "y.tab.c"
 }
 if(yychar==0)goto yyaccept;
 goto yyloop;
@@ -2945,7 +2940,7 @@ yyn<=4372&&yycheck[yyn]==yystate)
 yystate=yytable[yyn];
 else
 yystate=yydgoto[yym];
-# 3144 "y.tab.c"
+# 3148 "y.tab.c"
 if(yyssp>=yyss+500-1)
 {
 goto yyoverflow;
@@ -2963,17 +2958,16 @@ return(0);
 static char *_selTransTbl[] ={
 "strCopy",
 "gen",
-"iscompstmt",
 0
 };
 struct modDescriptor yacc_modDesc = {
   "yacc",
-  "objc3.1.31",
+  "objc3.1.32",
   0L,
   0,
   0,
   0,
-  3,
+  2,
   _selTransTbl,
   0
 };
